@@ -8,9 +8,13 @@ from typing import Callable
 import numpy as np
 
 from odat.utils.spectro import wf_to_spectr_func, DFLT_WIN_FUNC
+from odat.util import find_datapath
 
+dataname = 'conveyor_states.zip'
+ASSERT_SR = 44100
+DFLT_ZIP_FILE_PATH = find_datapath(dataname)
 
-def get_wf(wav_bytes, assert_sr=44100):
+def get_wf(wav_bytes, assert_sr=ASSERT_SR):
     wf, sr = sf.read(BytesIO(wav_bytes))
     if assert_sr is not None:
         assert sr == assert_sr, f"Sample rate was {sr}. I expected {assert_sr}"
@@ -37,7 +41,7 @@ dflt_wf_to_spectr = wf_to_spectr_func(
 
 @dataclass
 class Dacc:
-    zip_filepath: str
+    zip_filepath: str = DFLT_ZIP_FILE_PATH
     key_to_tag: Callable = key_to_tag
     wf_to_spectr: Callable = dflt_wf_to_spectr
 
@@ -75,7 +79,7 @@ class Dacc:
 
 
 _meta = dict(
-    name='conveyor_belts_01',
+    name='conveyor_belts_01.zip',
     description='Conveyor belts',
     mk_dacc=Dacc,
 )
